2D Data Processing Tutorial | MetaboLabPy

# MetaboLabPy

Advanced NMR Data Processing in Python

## Site Navigation[Skip]

- 1D Data Processing Tutorial
- 2D Data Processing Tutorial

## 2D Data Processing Tutorial

1. Press Ctrl+Shift+c

2. Read 2D data set and process NMR data using the proc2d.py script: Click on Script tab, then click Open Script and select proc2d.py. Click on eXecute Script.

3. Try out different window functions, window function parameters and TILT and Symmetrize parameters (Processing tab, se Dim2 tab to access processing paramters for indirect dimention). What is the effect on the resulting NMR spectrum and projec-tions?

4. Change window functions, TILT and symmetrisation options back to SEM (Dim1) and Sine (Dim2) and shift to 0.0 or both dimensions. Fourier transform the spectrum again.

5. Data Pre-Processing

> 1. Change to pJres (Data set 2)

> 2. Click Data Pre-Processing

> 3. Check Exclude Region, add 3 exclude regions (region left of the signals at ap-proximately 9.15 ppm, water region around 4.8 ppm and the area of TMSP and right of that signal)

> 4. Check Noise Filtering, set noise region and noise threshold

> 5. Check on Bucket spectra and zoom in on a signal containing region. What ef-fect do different settings have? Click run to see the effect and reset to reset to original spectra

> 6. Check Export DataSet, choose the option Excel Workbook, choose Samples in columns and set the exportPath and fileName by clicking set

> 7. Click run to export the pre-processed data set

Return to 1D Data Processing Tutorial

© Christian Ludwig 2020
[Back To Top]